#ifndef NT2_INCLUDE_CONSTANTS_NINE_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_NINE_HPP_INCLUDED

#include <nt2/constant/include/constants/nine.hpp>

#endif
